<?php

namespace Drupal\opigno_tincan_api\EventSubscriber;

use Drupal\Core\Link;
use Drupal\Core\Render\Markup;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Session\AccountInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\EventDispatcher\Event;
use Symfony\Component\HttpKernel\KernelEvents;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Class OpignoTincanLiveMeeting.
 */
class OpignoTincanApi implements EventSubscriberInterface {

  /** @var \Drupal\Core\Session\AccountInterface $currentUser */
  protected $user;

  /** @var \Drupal\Core\Routing\RouteMatchInterface $route */
  protected $route;

  /**
   * EventSubscriber constructor.
   */
  public function __construct(
    AccountInterface $current_user,
    RouteMatchInterface $route
  ) {
    $this->user = $current_user;
    $this->route = $route;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('current_user'),
      $container->get('current_route_match')
    );
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[KernelEvents::REQUEST][] = ['checkTincanPHPLibrary'];
    return $events;
  }

  /**
   * This method is called whenever the checkTincanPHPLibrary event is
   * dispatched.
   *
   * @param \Symfony\Component\EventDispatcher\Event $event
   *
   * @throws \Exception
   */
  public function checkTincanPhpLibrary(Event $event) {

    $messenger = \Drupal::messenger();

    // Check if Tincan PHP library is installed.
    $has_library = opigno_tincan_api_tincanphp_is_installed();
    if (!$has_library) {
      $messenger->addWarning(Markup::create("Please install the TinCanPHP library using Composer, with the command: <em>composer require rusticisoftware/tincan:@stable</em>"));
      return;
    }
    else {
      // Check if the LRS settings are set.
      $config = \Drupal::config('opigno_tincan_api.settings');
      $endpoint = $config->get('opigno_tincan_api_endpoint');
      $username = $config->get('opigno_tincan_api_username');
      $password = $config->get('opigno_tincan_api_password');

      if (empty($endpoint) || empty($username) || empty($password)) {
        $messenger->addWarning(t(
          'Please configure the LRS connection in the @setting_page.',
          ['@setting_page' => Link::createFromRoute('settings page', 'opigno_tincan_api.settings_form')->toString()]
        ));
        return;
      }
    }
  }

}

